==> okteta-14.11.90.tar.xz: okteta-14.11.90/kasten/gui/io/streamencoder/ihex/bytearrayihexstreamencoderconfigeditor.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYIHEXSTREAMENCODERCONFIGEDITOR_H
#define BYTEARRAYIHEXSTREAMENCODERCONFIGEDITOR_H

// lib
#include "bytearrayihexstreamencoder.h"
// Qt
#include <abstractmodelstreamencoderconfigeditor.h>

class KComboBox;


namespace Kasten
{

class ByteArrayIHexStreamEncoderConfigEditor : public AbstractModelStreamEncoderConfigEditor
{
  Q_OBJECT

  public:
    explicit ByteArrayIHexStreamEncoderConfigEditor( ByteArrayIHexStreamEncoder* encoder, QWidget* parent = 0 );
    virtual ~ByteArrayIHexStreamEncoderConfigEditor();

  public: // AbstractModelStreamEncoderConfigEditor API
    virtual AbstractSelectionView* createPreviewView() const;

  protected Q_SLOTS:
    void onSettingsChanged();

  protected:
    ByteArrayIHexStreamEncoder* mEncoder;
    IHexStreamEncoderSettings mSettings;

    KComboBox* mAddressSizeSelect;
};

}

#endif

==> okteta-16.11.80.tar.xz: okteta-16.11.80/kasten/gui/io/streamencoder/ihex/bytearrayihexstreamencoderconfigeditor.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYIHEXSTREAMENCODERCONFIGEDITOR_H
#define BYTEARRAYIHEXSTREAMENCODERCONFIGEDITOR_H

// lib
#include "bytearrayihexstreamencoder.h"
// Kasten gui
#include <kasten/abstractmodelstreamencoderconfigeditor.h>

class KComboBox;


namespace Kasten
{

class ByteArrayIHexStreamEncoderConfigEditor : public AbstractModelStreamEncoderConfigEditor
{
  Q_OBJECT

  public:
    explicit ByteArrayIHexStreamEncoderConfigEditor( ByteArrayIHexStreamEncoder* encoder, QWidget* parent = 0 );
    virtual ~ByteArrayIHexStreamEncoderConfigEditor();

  public: // AbstractModelStreamEncoderConfigEditor API
    virtual AbstractSelectionView* createPreviewView() const;

  protected Q_SLOTS:
    void onSettingsChanged();

  protected:
    ByteArrayIHexStreamEncoder* mEncoder;
    IHexStreamEncoderSettings mSettings;

    KComboBox* mAddressSizeSelect;
};

}

#endif
